import { EventEmitter, Component, Input, Output, HostListener, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

const DEFAULT_OPTIONS = {
    width: '500px',
    disableClose: false,
};
class NgxWhatsNewComponent {
    constructor() {
        /** Modals to show */
        this.items = [];
        /** Emits on close */
        this.closeModal = new EventEmitter();
        /** Index of the selected modal item */
        this.selected = 0;
    }
    /** Set some default options */
    set options(options) {
        this._options = Object.assign(Object.assign({}, DEFAULT_OPTIONS), options);
    }
    /**
     * Registers a listener for keyboard-based navigation between modals
     * @param $event keyboard event
     */
    navigateByKeyboard($event) {
        if (this._options.enableKeyboardNavigation) {
            switch ($event.key) {
                case 'ArrowRight':
                    if (this.selected < this.items.length - 1) {
                        this.selected = this.selected + 1;
                    }
                    break;
                case 'ArrowLeft':
                    if ($event.key === 'ArrowLeft' && this.selected > 0) {
                        this.selected = this.selected - 1;
                    }
                    break;
                case 'Escape':
                    this.close();
                    break;
                default:
                    break;
            }
        }
    }
    /**
     * Navigates to the next modal
     */
    goToNext() {
        if (this.selected < this.items.length - 1) {
            this.selected = this.selected + 1;
        }
        else {
            this.closeModal.emit();
        }
    }
    /**
     * Navigates to the modal with the provided index
     * @param index number of the modal window
     */
    navigateTo(index) {
        if (this._options.clickableNavigationDots) {
            this.selected = index;
        }
    }
    /**
     * Closes the modal dialog
     */
    close() {
        if (!this._options.disableClose) {
            this.closeModal.emit();
        }
    }
}
NgxWhatsNewComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-whats-new',
                template: "<div class=\"modal\">\n  <div class=\"modal-layout\">\n    <div\n      class=\"modal-body\"\n      [style.width]=\"_options.customStyle?.width\"\n      [style.border-radius]=\"_options.customStyle?.borderRadius\"\n      [style.border]=\"_options.customStyle?.borderSize\"\n      [style.boxShadow]=\"_options.customStyle?.boxShadow\"\n      [style.backgroundColor]=\"_options.customStyle?.backgroundColor\"\n      [style.color]=\"_options.customStyle?.textColor\"\n    >\n      <div\n        *ngIf=\"items[selected]?.imageSrc\"\n        class=\"image\"\n        [style.background-color]=\"items[selected]?.imageBgColor\"\n        [style.height]=\"items[selected]?.imageHeight + 'px'\"\n      >\n        <img [src]=\"items[selected]?.imageSrc\" />\n      </div>\n      <div class=\"title\" *ngIf=\"items[selected]?.title\">\n        {{ items[selected]?.title }}\n      </div>\n      <div class=\"text\" *ngIf=\"items[selected]?.text\">\n        {{ items[selected]?.text }}\n      </div>\n      <div\n        class=\"text\"\n        *ngIf=\"items[selected]?.html\"\n        [innerHTML]=\"items[selected]?.html\"\n      ></div>\n      <div\n        class=\"button\"\n        [style.text-align]=\"btn?.position || 'center'\"\n        *ngIf=\"items[selected]?.button as btn\"\n      >\n        <button\n          [style.background-color]=\"btn?.bgColor\"\n          [style.color]=\"btn?.textColor\"\n          (click)=\"goToNext()\"\n        >\n          {{ btn.text }}\n        </button>\n      </div>\n    </div>\n    <ul class=\"navigation\" *ngIf=\"items.length > 1\">\n      <li\n        class=\"dot\"\n        [class.clickable]=\"_options.clickableNavigationDots\"\n        (click)=\"navigateTo(i)\"\n        [class.active]=\"i === selected\"\n        [class.inactive]=\"i !== selected\"\n        *ngFor=\"let item of items; let i = index\"\n      ></li>\n    </ul>\n  </div>\n</div>\n<div id=\"backdrop\" (click)=\"close()\"></div>\n",
                styles: [".modal{height:auto;left:50%;position:fixed;top:50%;transform:translate(-50%,-50%);width:500px;z-index:1000}.modal-layout{display:-ms-grid;display:grid;place-content:center}.modal-layout .modal-body{background:#fff;overflow:hidden}.modal-layout .modal-body .image{align-items:center;display:flex;justify-content:center;overflow:hidden}.modal-layout .modal-body .title{font-size:1.3em;font-weight:100;margin:20px 20px 0;text-align:center}.modal-layout .modal-body .text{margin:20px;text-align:center}.modal-layout .modal-body .button{padding:0 20px 20px}.modal-layout .modal-body .button button{border:none;cursor:pointer;outline:none;padding:10px 35px;text-transform:uppercase}.modal-layout .modal-body .button button:hover{opacity:.9}.modal-layout .navigation{align-items:center;display:flex;justify-content:center;list-style-type:none;margin:20px;padding:0}.modal-layout .navigation .dot{border-radius:9999px;height:12px;margin:0 4px;width:12px}.modal-layout .navigation .active{background-color:rgba(0,0,0,.8);border:1px solid transparent}.modal-layout .navigation .inactive{background-color:transparent;border:1px solid rgba(0,0,0,.3)}.modal-layout .navigation .clickable .inactive{cursor:pointer}#backdrop{-webkit-backdrop-filter:blur(3px);backdrop-filter:blur(3px);background-color:rgba(0,0,0,.3);bottom:0;left:0;position:fixed;right:0;top:0;z-index:900}"]
            },] }
];
NgxWhatsNewComponent.propDecorators = {
    items: [{ type: Input }],
    options: [{ type: Input }],
    closeModal: [{ type: Output }],
    navigateByKeyboard: [{ type: HostListener, args: ['window:keydown', ['$event'],] }]
};

class NgxWhatsNewModule {
}
NgxWhatsNewModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxWhatsNewComponent],
                imports: [CommonModule],
                exports: [NgxWhatsNewComponent],
            },] }
];

/*
 * Public API Surface of ngx-whats-new
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxWhatsNewComponent, NgxWhatsNewModule };
//# sourceMappingURL=ngx-whats-new.js.map
